@@ -228,19 +228,18 @@ def provides(varmap):
 
 
 def add_vars(varmap):
-    """Automate adding ``long_description``, ``url``, and ``provides`` setup vars.
+    """Automate adding ``long_description`` and ``url`` setup vars.
     """
     
     if 'long_description' not in varmap:
         varmap['long_description'] = long_description(varmap)
     if 'url' not in varmap:
         varmap['url'] = pypi_url(varmap)
-    if 'provides' not in varmap:
-        varmap['provides'] = provides(varmap)
+    # provides format changed and it's not used anyway, so don't automatically include it
 
 
 def convert_lists(varmap,
-                  listnames=('classifiers', 'requires', 'provides', 'obsoletes')):
+                  listnames=('classifiers', 'install_requires')):
     """Convert long strings to lists of strings.
     
     Allows variable names in ``listnames`` to be specified as
@@ -821,9 +820,7 @@ distutils_keywords = dict(
     data_files=list,
     package_dir=str,
     package_data=dict,
-    requires=list,
-    provides=list,
-    obsoletes=list
+    install_requires=list
 )
 
 
